---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Is something not working as expected?**
Please edit this line and tell us what's not working.

**Steps to reproduce.**
Please help us reproduce the bug, by sharing:

1. your `gramex.yaml` configuration
2. the Python, HTML or JavaScript code
3. the Gramex log output, or browser console errors (if any)
4. a screenshot of the problem

**Expected behavior:**
Please tell us what should have happened?

**Your environment:**
 - OS: [e.g. Linux, OSX, Windows]
 - Browser: [e.g. Chrome, Firefox, Safari, IE]
 - Python version: [e.g. 3.7.2]
 - Gramex version: [e.g. 1.74.0]
